@@ -32,6 +32,7 @@ data BluetileRC = BluetileRC { defaultModifierBRC :: KeyMask
                                 , terminalBRC :: String
                                 , startDockBRC :: Bool
                                 , keysBRC :: [(String, (KeyMask, KeySym))]
+                                , decorationBRC :: [(String, String)]
                             } deriving (Show)
 
 maskKeywordsBRC :: [(String, KeyMask)]
@@ -392,8 +393,12 @@ parseConfigFile systemConfig userConfig = do
             startDockCF <- CF.get cp "DEFAULT" "start_dock"
             let maskKeywordsBRCwithDefault = maskKeywordsBRC' ++ [("defaultmod", defaultModifierCF)]
 
-            -- keys
+            -- theme
             itemsCF <- CF.items cp "DEFAULT"
+            let colorsCF = filter (\(k, _) -> isPrefixOf "decoration_" k) itemsCF
+                            ++ filter (\(k, _) -> isPrefixOf "window_border_" k) itemsCF
+
+            -- keys
             let keyBindingsCFstr = filter (\(k, _) -> isPrefixOf "key_" k) itemsCF
             keyBindingsCF <- mapM (parseKeyBinding maskKeywordsBRCwithDefault) keyBindingsCFstr
 
@@ -401,7 +406,9 @@ parseConfigFile systemConfig userConfig = do
                                         , focusFollowsMouseBRC = focusFollowsMouseCF
                                         , terminalBRC = terminalCF
                                         , startDockBRC = startDockCF
-                                        , keysBRC = keyBindingsCF }
+                                        , keysBRC = keyBindingsCF
+                                        , decorationBRC = colorsCF
+                                        }
             return bluetilerc
     case rv of
         (Left err) -> do
